@@ -33,7 +33,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 use warnings;
 use Carp;
@@ -60,7 +60,7 @@ our %field_conf = (
 
         my @dbxrefs =
           grep {
-            !m|^http:|;
+            !m|^http:| && /^\S+:\S+$/;
           } split /\s*,\s/, $dbxrefs;
 
         return {
